@@ -1,4 +1,4 @@
-with_example("slides.Rmd", {
+with_example("slides.Rmd", requires_chrome = TRUE, {
     # By default a png of only the first slide is built
     to_png("slides.Rmd", keep_intermediates = TRUE)
 
